#! /bin/bash

set -e

LOCALES="ja en"
TOUCH_DATETIME="minute=0,second=0"
BASEDIR="."
DATABASE_USER=kompira
MANAGE_PY="$BASEDIR/manage.py"

if [ ! -x $MANAGE_PY ]; then
    echo "ERROR: $MANAGE_PY not found!" > /dev/stderr
    exit 1
fi
if [[ ! -d "$BASEDIR/exported" || ! -d "$BASEDIR/kompira/fixtures" ]]; then
    echo "ERROR: invalid current directory!" > /dev/stderr
    exit 1
fi

export DJANGO_SETTINGS_MODULE=kompira_site.conf.local_settings

for locale in $LOCALES; do
    export KOMPIRA_DATABASE_NAME=kompira_fixtures_${locale}
    echo "*** create fixtures in database '$KOMPIRA_DATABASE_NAME' ***"
    createdb -U $DATABASE_USER --encoding=utf8 $KOMPIRA_DATABASE_NAME
    $MANAGE_PY migrate --noinput
    $MANAGE_PY create_initial_data --locale ${locale}
    $MANAGE_PY dump_coredata --touch --touch-datetime="$TOUCH_DATETIME" | jq . > $BASEDIR/kompira/fixtures/bootstrap_data-${locale}.json
    $MANAGE_PY import_data --overwrite $BASEDIR/exported/types-${locale}.dat $BASEDIR/exported/startup-${locale}.dat
    $MANAGE_PY dump_coredata --touch --touch-datetime="$TOUCH_DATETIME" | jq . > $BASEDIR/kompira/fixtures/startup-${locale}.json
    $MANAGE_PY import_data --overwrite $BASEDIR/exported/nodetypes.dat
    $MANAGE_PY dump_coredata --touch --touch-datetime="$TOUCH_DATETIME" | jq . > $BASEDIR/kompira/fixtures/allinone-${locale}.json
    dropdb -U $DATABASE_USER $KOMPIRA_DATABASE_NAME
done
